@@ -41,11 +41,12 @@ if [ x"$1" = "xhelp" ]; then
     usage
     exit 1
 fi
+lisp=${1:-sbcl} ; shift
 
-if [ -z "$2" ]; then
+if [ -z "$*" ]; then
     scripts="*.script"
 else
-    scripts="$2"
+    scripts="$*"
 fi
 
 sok=1
@@ -86,6 +87,7 @@ do_tests() {
     echo "  $test_pass passing and $test_fail failing" >&2
     if [ $test_fail -eq 0 ] ; then
 	echo "all tests apparently successful" >&2
+        echo success > ../tmp/results/status
     else
 	echo "failing test(s): $failed_list" >&2
     fi
@@ -97,23 +99,12 @@ do_tests() {
 # terminate on error
 set -e
 
-lisp=$1
-if [ -z $1 ] ; then
-    lisp="sbcl"
-fi
-
 command= flags= nodebug= eval=
 case "$lisp" in
-  sbcl)
-    command="${SBCL:-sbcl}"
-    flags="--noinform --userinit /dev/null --sysinit /dev/null"
-    nodebug="--disable-debugger"
+  abcl)
+    command="${ABCL:-abcl}"
+    flags="--noinit --noinform"
     eval="--eval" ;;
-  clisp)
-    command="${CLISP:-clisp}"
-    flags="-norc -ansi -I "
-    nodebug="-on-error exit"
-    eval="-x" ;;
   allegro)
     command="${ALLEGRO:-alisp}"
     flags="-q"
@@ -129,6 +120,11 @@ case "$lisp" in
     flags="--no-init --quiet"
     nodebug="--batch"
     eval="--eval" ;;
+  clisp)
+    command="${CLISP:-clisp}"
+    flags="-norc -ansi -I "
+    nodebug="-on-error exit"
+    eval="-x" ;;
   cmucl)
     command="${CMUCL:-lisp}"
     flags="-noinit"
@@ -138,6 +134,11 @@ case "$lisp" in
     command="${ECL:-ecl}"
     flags="-norc"
     eval="-eval" ;;
+  gclcvs)
+    export GCL_ANSI=t
+    command="${GCL:-gclcvs}"
+    flags="-batch"
+    eval="-eval" ;;
   lispworks)
     command="${LISPWORKS:-lispworks}"
     # If you have a licensed copy of lispworks,
@@ -146,15 +147,16 @@ case "$lisp" in
     # ./lispworks-6-0-0-x86-linux -siteinit - -init - -build /tmp/build.lisp
     flags="-siteinit - -init -"
     eval="-eval" ;;
-  gclcvs)
-    export GCL_ANSI=t
-    command="${GCL:-gclcvs}"
-    flags="-batch"
-    eval="-eval" ;;
-  abcl)
-    command="${ABCL:-abcl}"
-    flags="--noinit --noinform"
+  sbcl)
+    command="${SBCL:-sbcl}"
+    flags="--noinform --userinit /dev/null --sysinit /dev/null"
+    nodebug="--disable-debugger"
     eval="--eval" ;;
+  scl)
+    command="${SCL:-scl}"
+    flags="-noinit"
+    nodebug="-batch"
+    eval="-eval" ;;
   *)
     echo "Unsupported lisp: $1" >&2
     echo "Please add support to run-tests.sh" >&2
@@ -190,8 +192,11 @@ if [ -z "$command" ] ; then
 else
     create_config
     mkdir -p ../tmp/results
+    echo failure > ../tmp/results/status
     thedate=`date "+%Y-%m-%d"`
     do_tests "$command" "$eval" 2>&1 | \
 	tee "../tmp/results/${lisp}.text" "../tmp/results/${lisp}-${thedate}.save"
+    read a < ../tmp/results/status
     clean_up
+    [ success = "$a" ] ## exit code
 fi
